==> libggi-2.0b2.1.tar.gz: libggi-2.0b2.1/display/vgagl/box.c <==
/* $Id: box.c,v 1.9 1998/11/19 01:06:30 marcus Exp $
******************************************************************************

   SVGAlib target vgagl helper: box stubs

   Copyright (C) 1998 Marcus Sundberg   [marcus@ggi-project.org]
   Copyright (C) 1997 Jason McMullan    [jmcc@ggi-project.org]
   Copyright (C) 1995 Andreas Beck      [becka@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include <ggi/internal/ggi-dl.h>
#include "vgaglvis.h"


/**********************/
/* draw/get/put a box */
/**********************/
int GGI_vgagl_drawbox(ggi_visual *vis,int x,int y,int width,int height)
{
	if (y< (LIBGGI_GC(vis)->cliptl.y)) {
		int diff=(LIBGGI_GC(vis)->cliptl.y)-y;
		y     +=diff;
		height-=diff;
	}
	if (y+height>(LIBGGI_GC(vis)->clipbr.y)) {
		height=(LIBGGI_GC(vis)->clipbr.y)-y;
	}
	if (x< (LIBGGI_GC(vis)->cliptl.x)) {
		int diff=(LIBGGI_GC(vis)->cliptl.x)-x;
		x     +=diff;
		width-=diff;
	}
	if (x+width>(LIBGGI_GC(vis)->clipbr.x)) {
		width=(LIBGGI_GC(vis)->clipbr.x)-x;
	}

	if (height<=0 || width<=0 ) 
		return 0;

	gl_fillbox(x,y,width,height,LIBGGI_GC_FGCOLOR(vis));
	return 0;
}

int GGI_vgagl_putbox(ggi_visual *vis,int x,int y,int width,int height,void *buffer)
{ 
	int rowadd = LIBGGI_FB_W_STRIDE(vis);
	ggi_coord  tl=LIBGGI_GC(vis)->cliptl, br=LIBGGI_GC(vis)->clipbr;

	/* Pre-Clipping, so we don't call PutHline without need. */
	if (y< tl.y) {
		int diff=tl.y-y;
		y     +=diff;
		height-=diff;
		buffer = (uint8 *)(buffer)+rowadd*diff; 
	}
	if (y+height>=br.y) {
		height=br.y-y;
	}
	if (x< tl.x) {
		int diff=tl.x-x;
		x     +=diff;
		width -=diff;
		buffer = (uint8 *)(buffer)+diff;
		}
	if (x+width>=br.x) {
		width=br.x-x;
	}
	if (height>0&&width>0)
		gl_putbox(x,y,width,height,buffer);
	return 0;
}

int GGI_vgagl_getbox(ggi_visual *vis,int x,int y,int width,int height,void *buffer)
{ 
	/* Unclipped - get */
	gl_getbox(x,y,width,height,buffer);
	return 0;
}

==> libggi_2.0.5.orig.tar.gz: libggi-2.0.5.orig/display/vgagl/box.c <==
/* $Id: box.c,v 1.2 2002/09/08 21:37:47 soyt Exp $
******************************************************************************

   SVGAlib target vgagl helper: box stubs

   Copyright (C) 1998-1999 Marcus Sundberg   [marcus@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include "config.h"
#include <ggi/internal/ggi-dl.h>
#include "vgaglvis.h"


int GGI_vgagl_drawbox(ggi_visual *vis, int x, int y, int w, int h)
{
	LIBGGICLIP_XYWH(vis, x, y, w, h);

	gl_fillbox(x, y, w, h, LIBGGI_GC_FGCOLOR(vis));

	return 0;
}

int GGI_vgagl_putbox(ggi_visual *vis, int x, int y, int w, int h, void *buffer)
{ 
	int pixelsize = (LIBGGI_PIXFMT(vis)->size+7)/8;
	int rowadd = w * pixelsize;
	uint8 *buf = buffer;

	LIBGGICLIP_PUTBOX(vis, x, y, w, h, buf, rowadd, * pixelsize);

	gl_putbox(x, y, w, h, buf);

	return 0;
}

int GGI_vgagl_getbox(ggi_visual *vis, int x, int y, int w, int h, void *buffer)
{ 
	gl_getbox(x, y, w, h, buffer);

	return 0;
}
